@@ -102,6 +102,7 @@ KEY_COMPOSITE2 = 248
 KEY_DOWN = 20
 KEY_END = 123
 KEY_ENTER = 66
+KEY_ESCAPE = 111
 KEY_FAST_FORWARD = 90
 KEY_GREEN = 184
 KEY_HDMI1 = 243
@@ -196,6 +197,7 @@ KEYS = {"BACK": KEY_BACK,
         "DOWN": KEY_DOWN,
         "END": KEY_END,
         "ENTER": KEY_ENTER,
+        "ESCAPE": KEY_ESCAPE,
         "FAST_FORWARD": KEY_FAST_FORWARD,
         "GREEN": KEY_GREEN,
         "HDMI1": KEY_HDMI1,
